@@ -3,7 +3,7 @@
 #include <stdexcept>
 #include <Rcpp.h>
 #include "KDTree.h"
-#include <RProgress.h>
+//#include <RProgress.h>
 
 using namespace std;
 
@@ -21,11 +21,11 @@ vector<vector< double > > convertMatrixToVector(double array[], int nrow, int nc
 using namespace Rcpp;
 
 // [[Rcpp::export]]
-SEXP kdtree_build_intl(SEXP d, SEXP nr, SEXP nc, SEXP verb) // d is the numeric data, nr is the rows, nc is the cols
+SEXP kdtree_build_intl(SEXP d, SEXP nr, SEXP nc) // d is the numeric data, nr is the rows, nc is the cols
 {
   int nrow = as<int>(nr);
   int ncol = as<int>(nc);
-  bool verbose = as<int>(verb);
+  //bool verbose = as<int>(verb);
   NumericVector data(d);
   
   if(data.size() != nrow*ncol)
@@ -36,7 +36,7 @@ SEXP kdtree_build_intl(SEXP d, SEXP nr, SEXP nc, SEXP verb) // d is the numeric
   vector<vector< double > > dataMatrix
     = convertMatrixToVector(data.begin(), nrow, ncol);
   
-  KDTree *t = new KDTree(dataMatrix, verbose);
+  KDTree *t = new KDTree(dataMatrix);
   
   XPtr<KDTree> p(t, TRUE);
   
@@ -63,11 +63,11 @@ SEXP kdtree_ball_query_multiple(SEXP tr, SEXP ptlist, SEXP nr, SEXP nc, SEXP r,
     throw(length_error("Points not same dimensionality as data in kdtree"));  
   }
   
-  RProgress::RProgress pb("[:bar]", nrow);
+ //RProgress::RProgress pb("[:bar]", nrow);
   if (verbose==1)
   {
     Rcpp::Rcout << "Ball query... \n";
-    pb.tick(0);
+    //pb.tick(0);
   }
   
   for (int i=0; i<nrow; i++)
@@ -84,7 +84,7 @@ SEXP kdtree_ball_query_multiple(SEXP tr, SEXP ptlist, SEXP nr, SEXP nc, SEXP r,
     
     if (i%10==0 && verbose==1)
     {
-      pb.update(1.0*(i+1)/nrow);
+      //pb.update(1.0*(i+1)/nrow);
     }
     
   }
@@ -94,7 +94,7 @@ SEXP kdtree_ball_query_multiple(SEXP tr, SEXP ptlist, SEXP nr, SEXP nc, SEXP r,
     Rcpp::Rcout << "\ndone.\n";
   }
   
-  pb.update(1);
+  //pb.update(1);
   
   return(wrap(finalCounts));
 }
@@ -119,11 +119,11 @@ SEXP kdtree_ball_query_id_multiple(SEXP tr, SEXP ptlist, SEXP nr, SEXP nc, SEXP
     throw(length_error("Points not same dimensionality as data in kdtree"));  
   }
   
-  RProgress::RProgress pb("[:bar]", nrow);
+  //RProgress::RProgress pb("[:bar]", nrow);
   if (verbose==1)
   {
     Rcpp::Rcout << "Ball query... \n";
-    pb.tick(0);
+    //pb.tick(0);
   }
   
   for (int i=0; i<nrow; i++)
@@ -149,11 +149,11 @@ SEXP kdtree_ball_query_id_multiple(SEXP tr, SEXP ptlist, SEXP nr, SEXP nc, SEXP
     
     if (i%10==0 && verbose==1)
     {
-      pb.update(1.0*(i+1)/nrow);
+      //pb.update(1.0*(i+1)/nrow);
     }
   }
   
-  pb.update(1);
+  //pb.update(1);
   
   if (verbose==1)
   {
@@ -190,11 +190,11 @@ SEXP kdtree_range_query_multiple(SEXP tr, SEXP pminlist, SEXP pmaxlist, SEXP nr,
     throw(length_error("Points not same dimensionality as data in kdtree"));  
   }
   
-  RProgress::RProgress pb("[:bar]", nrow);
+  //RProgress::RProgress pb("[:bar]", nrow);
   if (verbose==1)
   {
     Rcpp::Rcout << "Ball query... \n";
-    pb.tick(0);
+    //pb.tick(0);
   }
   
   for (int i=0; i<nrow; i++)
@@ -210,13 +210,13 @@ SEXP kdtree_range_query_multiple(SEXP tr, SEXP pminlist, SEXP pmaxlist, SEXP nr,
     
     if (i%10==0 && verbose==1)
     {
-      pb.update(1.0*(i+1)/nrow);
+      //pb.update(1.0*(i+1)/nrow);
     }
     
     
   }
   
-  pb.update(1);
+  //pb.update(1);
   
   if (verbose==1)
   {
